@@ -28,7 +28,7 @@ use Excel::Writer::XLSX::Package::XMLwriter;
 use Excel::Writer::XLSX::Utility qw(xl_cell_to_rowcol xl_rowcol_to_cell);
 
 our @ISA     = qw(Excel::Writer::XLSX::Package::XMLwriter);
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 
 ###############################################################################
@@ -519,7 +519,7 @@ sub set_codepage {
 sub _store_workbook {
 
     my $self     = shift;
-    my $dir      = tempdir();
+    my $dir      = tempdir( CLEANUP => 1 );
     my $packager = Excel::Writer::XLSX::Package::Packager->new();
     my $zip      = Archive::Zip->new();
 
